#!/usr/bin/python
__author__ = 'Piotr Matuszczyk <piotr.matuszczyk@sap.com>'

import json, os
from jinja2 import Environment, FileSystemLoader
from jinja2.exceptions import TemplateNotFound
from time import sleep

class Vrarequest:
  def __init__(self, templatepath):
    self.templatepath = templatepath
  requestid = None
  errorlist = [0]
  url = None
  payload = None
  
  def createPayloadFromTemplate(self, o, customer, reqdata, defaultvars):
    try:
      templateloader = FileSystemLoader(searchpath=os.path.dirname(self.templatepath))
      templateenv = Environment(loader=templateloader, autoescape=True)
      template = templateenv.get_template(os.path.split(self.templatepath)[1])
      rendervars = {'catalog': o.catalogtemp, 'defaultvars': defaultvars, 'reqdata': reqdata, 'customer': customer}
      self.payload = json.loads(template.render(rendervars))
    except TemplateNotFound, e:
      self.errorlist[0] = 1
      self.errorlist.append('Template does not exist: %s' %e)
  
  def findRequestId(self, o):
    self.requestid = o.response.headers['Location'].split('/')[-1]
  
  def checkRequestFinalStatus(self, o, wait_time):
    url = '/catalog-service/api/consumer/requests/'+self.requestid
    w = 0
    while w < wait_time:
      o.sendGETRequest(url)
      if o.errorlist[0] == 1:
        break
      w = w + 5
      if (o.response.json()['state'] == 'SUCCESSFUL' or o.response.json()['state'] == 'FAILED' or o.response.json()['state'] == 'PROVIDER_FAILED'):
        if (o.response.json()['state'] == 'FAILED' or o.response.json()['state'] == 'PROVIDER_FAILED'):
          self.errorlist[0] = 1
          self.errorlist.append(o.response.json()['requestCompletion']['completionDetails']+'   Request number: '+str(o.response.json()['requestNumber'])+'  Request id: '+self.requestid)
          break
        break
      sleep(5)
    else:
      self.errorlist[0] = 1
      self.errorlist.append('Wait timeout exceeded (wait_timeout: '+str(wait_time)+'). Last request STATE: '+o.response.json()['state']+'. Request number: '+str(o.response.json()['requestNumber'])+'  Request id: '+self.requestid)